==> igniteui-react-18.2.2-beta.0.tgz: package/esm2015/lib/Avatar.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { BaseElement } from "./BaseElement";
import { WCNativeHelper } from "./WCNativeHelper";
import { enumGetBox, EnumUtil, markType } from "igniteui-react-core";
import { AvatarShape_$type } from "./AvatarShape";
import { SizableComponentSize_$type } from "./SizableComponentSize";
/**
 * @hidden
 */
export let Avatar = /*@__PURE__*/ (() => {
    class Avatar extends BaseElement {
        constructor() {
            super(...arguments);
            this.c = new WCNativeHelper();
            this.e = null;
        }
        get d() {
            return this.c;
        }
        get nativeElement() {
            return this.e;
        }
        set nativeElement(a) {
            this.e = a;
            this.c.n = this.e;
        }
        setNativeElement(a) {
            this.nativeElement = a;
        }
        get i() {
            let ret_ = this.d.m("src");
            return ret_;
        }
        set i(a) {
            let value_ = a;
            this.d.u("src", value_);
        }
        get g() {
            let ret_ = this.d.m("alt");
            return ret_;
        }
        set g(a) {
            let value_ = a;
            this.d.u("alt", value_);
        }
        get h() {
            let ret_ = this.d.m("initials");
            return ret_;
        }
        set h(a) {
            let value_ = a;
            this.d.u("initials", value_);
        }
        get a() {
            let ret_ = this.d.m("shape");
            ret_ = enumGetBox(AvatarShape_$type, EnumUtil.getEnumValue(AvatarShape_$type, this.d.f(AvatarShape_$type, ret_)));
            return EnumUtil.getEnumValue(AvatarShape_$type, ret_);
        }
        set a(a) {
            let value_ = enumGetBox(AvatarShape_$type, a);
            value_ = WCNativeHelper.o(value_.toString());
            this.d.u("shape", value_);
        }
        get b() {
            let ret_ = this.d.m("size");
            ret_ = enumGetBox(SizableComponentSize_$type, EnumUtil.getEnumValue(SizableComponentSize_$type, this.d.f(SizableComponentSize_$type, ret_)));
            return EnumUtil.getEnumValue(SizableComponentSize_$type, ret_);
        }
        set b(a) {
            let value_ = enumGetBox(SizableComponentSize_$type, a);
            value_ = WCNativeHelper.o(value_.toString());
            this.d.u("size", value_);
        }
    }
    Avatar.$t = /*@__PURE__*/ markType(Avatar, 'Avatar', BaseElement.$);
    return Avatar;
})();

==> igniteui-react-18.3.0-beta.0.tgz: package/esm2015/lib/Avatar.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { BaseElement } from "./BaseElement";
import { WCNativeHelper } from "./WCNativeHelper";
import { enumGetBox, EnumUtil, markType } from "igniteui-react-core";
import { AvatarShape_$type } from "./AvatarShape";
import { SizableComponentSize_$type } from "./SizableComponentSize";
/**
 * @hidden
 */
export let Avatar = /*@__PURE__*/ (() => {
    class Avatar extends BaseElement {
        constructor() {
            super(...arguments);
            this.c = new WCNativeHelper();
            this.e = null;
        }
        get d() {
            return this.c;
        }
        get nativeElement() {
            return this.e;
        }
        set nativeElement(a) {
            this.e = a;
            this.c.o = this.e;
        }
        setNativeElement(a) {
            this.nativeElement = a;
        }
        get i() {
            let ret_ = this.d.n("src");
            return ret_;
        }
        set i(a) {
            let value_ = a;
            this.d.v("src", value_);
        }
        get g() {
            let ret_ = this.d.n("alt");
            return ret_;
        }
        set g(a) {
            let value_ = a;
            this.d.v("alt", value_);
        }
        get h() {
            let ret_ = this.d.n("initials");
            return ret_;
        }
        set h(a) {
            let value_ = a;
            this.d.v("initials", value_);
        }
        get a() {
            let ret_ = this.d.n("shape");
            ret_ = enumGetBox(AvatarShape_$type, EnumUtil.getEnumValue(AvatarShape_$type, this.d.f(AvatarShape_$type, ret_)));
            return EnumUtil.getEnumValue(AvatarShape_$type, ret_);
        }
        set a(a) {
            let value_ = enumGetBox(AvatarShape_$type, a);
            value_ = WCNativeHelper.p(value_.toString());
            this.d.v("shape", value_);
        }
        get b() {
            let ret_ = this.d.n("size");
            ret_ = enumGetBox(SizableComponentSize_$type, EnumUtil.getEnumValue(SizableComponentSize_$type, this.d.f(SizableComponentSize_$type, ret_)));
            return EnumUtil.getEnumValue(SizableComponentSize_$type, ret_);
        }
        set b(a) {
            let value_ = enumGetBox(SizableComponentSize_$type, a);
            value_ = WCNativeHelper.p(value_.toString());
            this.d.v("size", value_);
        }
    }
    Avatar.$t = /*@__PURE__*/ markType(Avatar, 'Avatar', BaseElement.$);
    return Avatar;
})();
